/*
 * This file is part of the SOAFaces Project (hereinafter "SOAFaces").
 * Copyright (C) 2006 Grand Logic, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.soafaces.bundle.client.rpc;

import com.google.gwt.user.client.rpc.AsyncCallback;

/**
 * <p>
 * Callback for fetching TaskletStatus object associated with a job run.
 * </p>
 *
 * <p>
 *  The posssible <code>onFailure()</code> exceptions that can be returned
 *  if there is a problem include:
 * <ul>
 *  <li><code>BeanTransferException</code> where there is a server-side problem
 *   fetching the JavaBean.</li>
 *  <li>Standard RPC exceptions that can be thrown by GWT.</li>
 * </ul>
 * </p>
 * @author Sam Taha
 */
public abstract class FetchTaskletStatusCallback implements AsyncCallback {

  public FetchTaskletStatusCallback() {
  }

  /**
   * Implement this method to process response from RPC and return TaskletStatus
   * object.
   * 
   * @param result Returns POJO object.
   */
  public abstract void onFetchTaskletStatusSuccess(TaskletStatus result);

  final public void onSuccess(Object result) {
    onFetchTaskletStatusSuccess((TaskletStatus) result);
  }
}
